==> libstdc++-2.90.6.1.tar.bz2: libstdc++-2.90.6.1/src/stl-inst.cc <==
// Explicit instantiation file.

// Copyright (C) 1999 Cygnus Solutions
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

//
// ISO C++ 14882:
//

#include <bits/c++config.h>
#include <bits/stl_config.h>
#include <bits/stl_alloc.h>
#include <bits/std_vector.h>

namespace std {

  template class __malloc_alloc_template<0>;

#ifndef __USE_MALLOC
  template class __default_alloc_template<__NODE_ALLOCATOR_THREADS, 0>;
#endif

  template
    void
    vector<unsigned int>::
    _M_insert_aux(__normal_iterator<unsigned int *, vector<unsigned int> >, 
		  unsigned int const &);

} //std

==> libstdc++-2.90.7.tar.bz2: libstdc++-2.90.7/src/stl-inst.cc <==
// Explicit instantiation file.

// Copyright (C) 1999 Cygnus Solutions
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

//
// ISO C++ 14882:
//

#include <bits/c++config.h>
#include <bits/stl_config.h>
#include <bits/stl_alloc.h>
#include <bits/std_vector.h>

namespace std {

  template class __malloc_alloc_template<0>;

#ifndef __USE_MALLOC
  template class __default_alloc_template<__NODE_ALLOCATOR_THREADS, 0>;
#endif

  template
    void
    vector<unsigned int>::
    _M_insert_aux(vector<unsigned int>::iterator, unsigned int const &);

} //std
